var EARTH_RADIUS = 6378137.0;    //单位M
var PI = Math.PI;
    
function getRad(d){
    return d*PI/180.0;
}

/**
 * 根据坐标获得距离
 */
function getDistance(lat1,lng1,lat2,lng2){
    var radLat1 = getRad(lat1);
    var radLat2 = getRad(lat2);
    
    var a = radLat1 - radLat2;
    var b = getRad(lng1) - getRad(lng2);
    
    var s = 2*Math.asin(Math.sqrt(Math.pow(Math.sin(a/2),2) + Math.cos(radLat1)*Math.cos(radLat2)*Math.pow(Math.sin(b/2),2)));
    s = s*EARTH_RADIUS;
    s = Math.round(s*10000)/10000000.0;
    s = s.toFixed(2);
    return s;
}

/** 
 * 火星坐标系 (GCJ-02) 与百度坐标系 (BD-09) 的转换算法 将 GCJ-02 坐标转换成 BD-09 坐标 
 *  
 * @param gg_lat 
 * @param gg_lon 
 */  
function gcj02_To_Bd09(gg_lat,gg_lon){
    var x = gg_lon, y = gg_lat;  
    var z = Math.sqrt(x * x + y * y) + 0.00002 * Math.sin(y * PI);
    var theta = Math.atan2(y, x) + 0.000003 * Math.cos(x * PI); 
    var bd_lon = z * Math.cos(theta) + 0.0065;
    var bd_lat = z * Math.sin(theta) + 0.006;
    var bd_loc = [bd_lat,bd_lon]; 
    return bd_loc;
}

/** 
     * * 火星坐标系 (GCJ-02) 与百度坐标系 (BD-09) 的转换算法 * * 将 BD-09 坐标转换成GCJ-02 坐标 * * @param 
     * bd_lat * @param bd_lon * @return 
     */  
function bd09_To_Gcj02(bd_lat,bd_lon) {
    var x = bd_lon - 0.0065;
    var y = bd_lat - 0.006;  
    var z = Math.sqrt(x * x + y * y) - 0.00002 * Math.sin(y * PI);  
    var theta = Math.atan2(y, x) - 0.000003 * Math.cos(x * PI);  
    var gg_lon = z * Math.cos(theta);  
    var gg_lat = z * Math.sin(theta);
    var gg_loc = [gg_lat,gg_lon];
    return gg_loc;  
}  